@@ -3,7 +3,8 @@
 ;; Copyright (C) 2011-2024 EditorConfig Team
 
 ;; Author: EditorConfig Team <editorconfig@googlegroups.com>
-;; Version: 0.11.0
+;; Package-Version: 20250905.724
+;; Package-Revision: 4af10445fcdf
 ;; URL: https://github.com/editorconfig/editorconfig-emacs#readme
 ;; Package-Requires: ((emacs "27.2"))
 ;; Keywords: convenience editorconfig
@@ -75,7 +76,7 @@ Used by `editorconfig--execute-editorconfig-exec'."
   'editorconfig-get-properties-function
   "0.5")
 (defcustom editorconfig-get-properties-function
-  #'editorconfig-core-get-properties-hash
+  'editorconfig-core-get-properties-hash
   "A function which gets EditorConfig properties for specified file.
 
 This function will be called with one argument, full path of the target file,
@@ -172,6 +173,7 @@ This hook will be run even when there are no matching sections in
   ;; For contributors: Sort modes in alphabetical order
   '((ada-mode ada-indent)
     (ada-ts-mode ada-ts-mode-indent-offset)
+    (apache-mode apache-indent-level)
     (awk-mode c-basic-offset)
     (bash-ts-mode sh-basic-offset
                   sh-indentation)
@@ -179,19 +181,26 @@ This hook will be run even when there are no matching sections in
     (c++-mode c-basic-offset)
     (c++-ts-mode c-basic-offset
                  c-ts-mode-indent-offset)
+    (c-mode c-basic-offset)
     (c-ts-mode c-basic-offset
                c-ts-mode-indent-offset)
     (cmake-mode cmake-tab-width)
     (cmake-ts-mode cmake-tab-width
                    cmake-ts-mode-indent-offset)
     (coffee-mode coffee-tab-width)
+    (cperl-mode cperl-indent-level)
+    (crystal-mode crystal-indent-level)
     (csharp-mode c-basic-offset)
     (csharp-ts-mode c-basic-offset
                     csharp-ts-mode-indent-offset)
+    (css-mode css-indent-offset)
     (css-ts-mode css-indent-offset)
     (d-mode c-basic-offset)
     (elixir-ts-mode elixir-ts-indent-offset)
-    (emacs-lisp-mode . editorconfig--get-indentation-lisp-mode)
+    (emacs-lisp-mode . editorconfig-set-indentation-lisp-mode)
+    (enh-ruby-mode enh-ruby-indent-level)
+    (erlang-mode erlang-indent-level)
+    (ess-mode ess-indent-offset)
     (f90-mode f90-associate-indent
               f90-continuation-indent
               f90-critical-indent
@@ -204,9 +213,12 @@ This hook will be run even when there are no matching sections in
     (fsharp-mode fsharp-continuation-offset
                  fsharp-indent-level
                  fsharp-indent-offset)
+    (gdscript-mode gdscript-indent-offset)
     (go-ts-mode go-ts-mode-indent-offset)
     (gpr-mode gpr-indent)
     (gpr-ts-mode gpr-ts-mode-indent-offset)
+    (graphql-mode graphql-indent-level)
+    (groovy-mode groovy-indent-offset)
     (haskell-mode haskell-indent-spaces
                   haskell-indent-offset
                   haskell-indentation-layout-offset
@@ -216,31 +228,43 @@ This hook will be run even when there are no matching sections in
                   haskell-indentation-where-pre-offset
                   shm-indent-spaces)
     (haxor-mode haxor-tab-width)
+    (hcl-mode hcl-indent-level)
     (html-ts-mode html-ts-mode-indent-offset)
     (idl-mode c-basic-offset)
     (jade-mode jade-tab-width)
     (java-mode c-basic-offset)
     (java-ts-mode c-basic-offset
                   java-ts-mode-indent-offset)
+    (js-mode js-indent-level)
     (js-ts-mode js-indent-level)
     (js-json-mode js-indent-level)
     (js-jsx-mode js-indent-level sgml-basic-offset)
+    (js2-mode js2-basic-offset)
     (js2-jsx-mode js2-basic-offset sgml-basic-offset)
+    (js3-mode js3-indent-level)
     (json-mode js-indent-level)
     (json-ts-mode json-ts-mode-indent-offset)
     (jsonian-mode jsonian-default-indentation)
+    (julia-mode julia-indent-offset)
     (kotlin-mode kotlin-tab-width)
     (kotlin-ts-mode kotlin-ts-mode-indent-offset)
-    (latex-mode . editorconfig--get-indentation-latex-mode)
-    (lisp-mode . editorconfig--get-indentation-lisp-mode)
+    (latex-mode . editorconfig-set-indentation-latex-mode)
+    (lisp-mode . editorconfig-set-indentation-lisp-mode)
     (livescript-mode livescript-tab-width)
+    (lua-mode lua-indent-level)
+    (lua-ts-mode lua-ts-indent-offset)
+    (magik-mode magik-indent-level)
     (magik-ts-mode magik-indent-level)
+    (matlab-mode matlab-indent-level)
     (meson-mode meson-indent-basic)
     (mips-mode mips-tab-width)
     (mustache-mode mustache-basic-offset)
-    (nxml-mode . editorconfig--get-indentation-nxml-mode)
+    (nasm-mode nasm-basic-offset)
+    (nginx-mode nginx-indent-level)
+    (nxml-mode nxml-child-indent (nxml-attribute-indent . 2))
     (objc-mode c-basic-offset)
     (octave-mode octave-block-offset)
+    (perl-mode perl-indent-level)
     ;; No need to change `php-mode-coding-style' value for php-mode
     ;; since we run editorconfig later than it resets `c-basic-offset'.
     ;; See https://github.com/editorconfig/editorconfig-emacs/issues/116
@@ -251,20 +275,30 @@ This hook will be run even when there are no matching sections in
     (protobuf-mode c-basic-offset)
     (ps-mode ps-mode-tab)
     (pug-mode pug-tab-width)
-    (python-mode . editorconfig--get-indentation-python-mode)
-    (python-ts-mode . editorconfig--get-indentation-python-mode)
+    (puppet-mode puppet-indent-level)
+    (python-mode . editorconfig-set-indentation-python-mode)
+    (python-ts-mode . editorconfig-set-indentation-python-mode)
     (rjsx-mode js-indent-level sgml-basic-offset)
+    (ruby-mode ruby-indent-level)
     (ruby-ts-mode ruby-indent-level)
+    (rust-mode rust-indent-offset)
     (rust-ts-mode rust-indent-offset
                   rust-ts-mode-indent-offset)
+    (rustic-mode rustic-indent-offset)
     (scala-mode scala-indent:step)
     (scss-mode css-indent-offset)
+    (sgml-mode sgml-basic-offset)
     (sh-mode sh-basic-offset sh-indentation)
+    (slim-mode slim-indent-offset)
+    (sml-mode sml-indent-level)
+    (svelte-mode svelte-basic-offset)
     (swift-mode swift-mode:basic-offset)
+    (terra-mode terra-indent-level)
     (tcl-mode tcl-indent-level
               tcl-continued-indent-level)
     (templ-ts-mode go-ts-mode-indent-offset js-indent-level)
     (toml-ts-mode toml-ts-mode-indent-offset)
+    (typescript-mode typescript-indent-level)
     (typescript-ts-base-mode typescript-ts-mode-indent-offset)
     (verilog-mode verilog-indent-level
                   verilog-indent-level-behavioral
@@ -272,21 +306,43 @@ This hook will be run even when there are no matching sections in
                   verilog-indent-level-module
                   verilog-cexp-indent
                   verilog-case-indent)
-    (web-mode . editorconfig--get-indentation-web-mode)
-    (yaml-ts-mode yaml-indent-offset))
+    (web-mode (web-mode-indent-style . (lambda (size) 2))
+              web-mode-attr-indent-offset
+              web-mode-attr-value-indent-offset
+              web-mode-code-indent-offset
+              web-mode-css-indent-offset
+              web-mode-markup-indent-offset
+              web-mode-sql-indent-offset
+              web-mode-block-padding
+              web-mode-script-padding
+              web-mode-style-padding)
+    (yaml-mode yaml-indent-offset)
+    (yaml-ts-mode yaml-indent-offset)
+    (zig-mode zig-indent-offset))
   "Alist of indentation setting methods by modes.
 
-This is a fallback used for those modes which don't set
-`editorconfig-indent-size-vars'.
+Each element looks like (MODE . FUNCTION) or (MODE . INDENT-SPEC-LIST).
 
-Each element looks like (MODE . FUNCTION) or (MODE . VARLIST).
+If FUNCTION is provided, it will be called when setting the
+indentation.  The indent size will be passed.
 
-If FUNCTION is provided, it will be called with one argument (the indent size)
-when setting the indentation.  It should return the list of settings that need
-to be applied, where each setting has the form (VARIABLE . VALUE).
+If INDENT-SPEC-LIST is provided, each element of it must have one of the
+following forms:
 
-If VARLIST is provided, each element of VARLIST should be the name of
-a variable that we should set to the indent size.
+ 1. VARIABLE
+    It means (VARIABLE . 1).
+
+ 2. (VARIABLE . SPEC)
+    Setting VARIABLE according to the type of SPEC:
+
+      - Integer
+        The value is (* SPEC INDENT-SIZE);
+
+      - Function
+        The value is (funcall SPEC INDENT-SIZE);
+
+      - Any other type.
+        The value is SPEC.
 
 NOTE: Only the **buffer local** value of VARIABLE will be set."
   :type '(alist :key-type symbol :value-type sexp)
@@ -308,17 +364,18 @@ When variable `buffer-file-name' matches any of the regexps, then
                                    (eval (file-truename (expand-file-name recentf-save-file))))
                              t)))
 
-(defcustom editorconfig-trim-whitespaces-mode
-  (when (fboundp 'delete-trailing-whitespace-mode)
-    #'delete-trailing-whitespace-mode)
+(defcustom editorconfig-trim-whitespaces-mode nil
   "Buffer local minor-mode to use to trim trailing whitespaces.
 
 If set, enable that mode when `trim_trailing_whitespace` is set to true.
 Otherwise, use `delete-trailing-whitespace'."
-  :type 'function)
+  :type 'symbol)
 
-(defvar-local editorconfig-properties-hash nil
-  "Hash object of EditorConfig properties that was enabled for current buffer.")
+(defvar editorconfig-properties-hash nil
+  "Hash object of EditorConfig properties that was enabled for current buffer.
+Set by `editorconfig-apply' and nil if that is not invoked in
+current buffer yet.")
+(make-variable-buffer-local 'editorconfig-properties-hash)
 (put 'editorconfig-properties-hash
      'permanent-local
      t)
@@ -372,46 +429,35 @@ Make a message by passing ARGS to `format-message'."
   (and (stringp string)
        (string-match-p "\\`[0-9]+\\'" string)))
 
-(defun editorconfig--get-indentation-web-mode (size)
-  `((web-mode-indent-style . 2)
-    (web-mode-attr-indent-offset       . ,size)
-    (web-mode-attr-value-indent-offset . ,size)
-    (web-mode-code-indent-offset       . ,size)
-    (web-mode-css-indent-offset        . ,size)
-    (web-mode-markup-indent-offset     . ,size)
-    (web-mode-sql-indent-offset        . ,size)
-    (web-mode-block-padding            . ,size)
-    (web-mode-script-padding           . ,size)
-    (web-mode-style-padding            . ,size)))
+(defun editorconfig-set-indentation-python-mode (size)
+  "Set `python-mode' indent size to SIZE."
+  (when (boundp 'python-indent-offset)
+    (setq-local python-indent-offset size))
+  ;; For https://gitlab.com/python-mode-devs/python-mode
+  (when (boundp 'py-indent-offset)
+    (setq-local py-indent-offset size)))
 
-(defun editorconfig--get-indentation-python-mode (size)
-  "Vars to set `python-mode' indent size to SIZE."
-  `((python-indent-offset . ,size)      ;For python.el
-    (py-indent-offset . ,size)))        ;For python-mode.el
+(defun editorconfig-set-indentation-latex-mode (size)
+  "Set `latex-mode' indent size to SIZE."
+  (setq-local tex-indent-basic size)
+  (setq-local tex-indent-item size)
+  (setq-local tex-indent-arg (* 2 size))
+  ;; For AUCTeX
+  (when (boundp 'TeX-brace-indent-level)
+    (setq-local TeX-brace-indent-level size))
+  (when (boundp 'LaTeX-indent-level)
+    (setq-local LaTeX-indent-level size))
+  (when (boundp 'LaTeX-item-indent)
+    (setq-local LaTeX-item-indent (- size))))
 
-(defun editorconfig--get-indentation-latex-mode (size)
-  "Vars to set `latex-mode' indent size to SIZE."
-  `((tex-indent-basic . ,size)
-    (tex-indent-item . ,size)
-    (tex-indent-arg . ,(* 2 size))
-    ;; For AUCTeX
-    (TeX-brace-indent-level . ,size)
-    (LaTeX-indent-level . ,size)
-    (LaTeX-item-indent . ,(- size))))
-
-(defun editorconfig--get-indentation-nxml-mode (size)
-  "Vars to set `nxml-mode' indent size to SIZE."
-  `((nxml-child-indent . ,size)
-    (nxml-attribute-indent . ,(* 2 size))))
-
-(defun editorconfig--get-indentation-lisp-mode (size)
-  "Set indent size to SIZE for Lisp mode(s)."
-  (when (cond ((null editorconfig-lisp-use-default-indent)  t)
-              ((eql t editorconfig-lisp-use-default-indent) nil)
-              ((numberp editorconfig-lisp-use-default-indent)
-               (not (eql size editorconfig-lisp-use-default-indent)))
-              (t t))
-    `((lisp-indent-offset . ,size))))
+(defun editorconfig-set-indentation-lisp-mode (size)
+ "Set indent size to SIZE for Lisp mode(s)."
+ (when (cond ((null editorconfig-lisp-use-default-indent)  t)
+             ((eql t editorconfig-lisp-use-default-indent) nil)
+             ((numberp editorconfig-lisp-use-default-indent)
+              (not (eql size editorconfig-lisp-use-default-indent)))
+             (t t))
+   (setq-local lisp-indent-offset size)))
 
 (cl-defun editorconfig--should-set (symbol)
   "Determine if editorconfig should set SYMBOL."
@@ -431,117 +477,58 @@ Make a message by passing ARGS to `format-message'."
 
   t)
 
-(defvar editorconfig-indent-size-vars
-  #'editorconfig--default-indent-size-function
-  "Rule to use to set a given `indent_size'.
-This should hold the list of variables that need to be set to SIZE
-to tell the indentation code of the current major mode to use a basic
-indentation step of size SIZE.
-It can also take the form of a function, in which case we call it with
-a single SIZE argument (an integer) and it should return a list
-of (VAR . VAL) pairs indicating the variables to set and the values to
-set them to.
-Major modes are expected to set this buffer-locally.")
-
-(defun editorconfig--default-indent-size-function (size)
- "Guess which variables to set to for the indentation step to have size SIZE.
-This relies on `editorconfig-indentation-alist' supplemented with a crude
-heuristic for those modes not found there."
-  (let ((parents (if (fboundp 'derived-mode-all-parents) ;Emacs-30
-                     (derived-mode-all-parents major-mode)
-                   (let ((modes nil)
-                         (mode major-mode))
-                     (while mode
-                       (push mode modes)
-                       (setq mode (get mode 'derived-mode--parent)))
-                     (nreverse modes))))
-        entry)
-    (let ((parents parents))
-      (while (and parents (not entry))
-        (setq entry (assq (pop parents) editorconfig-indentation-alist))))
-    (or
-     (when entry
-       (let ((rule (cdr entry)))
-         ;; Filter out settings of unknown vars.
-         (delq nil
-               (mapcar
-                (lambda (elem)
-                  (let ((v (car elem)))
-                    (cond
-                     ((not (symbolp v))
-                      (message "Unsupported element in `editorconfig-indentation-alist': %S" elem))
-                     ((boundp v) elem))))
-                (if (functionp rule)
-                    (let ((result (funcall rule size)))
-                      (if (and (consp (car-safe result))
-                               (boundp (caar result)))
-                          result
-                        (message "Invalid return value for: %S"
-                                 rule)
-                        nil))
-                  (mapcar
-                   (lambda (elem)
-                     (cond
-                      ((symbolp elem) `(,elem . ,size))
-                      ((consp elem)
-                       (message "Old-style entry in editorconfig-indentation-alist: %S" elem)
-                       `(,(car elem)
-                         . ,(let ((spec (cdr elem)))
-                              (cond ((functionp spec) (funcall spec size))
-                                    ((integerp spec) (* spec size))
-                                    (t spec)))))))
-                   rule))))))
-     ;; Fallback, let's try and guess.
-     (let ((suffixes '("-indent-level" "-basic-offset" "-indent-offset"))
-           (guess ()))
-       (while (and parents (not guess))
-         (let* ((mode (pop parents))
-                (modename (symbol-name mode))
-                (name (substring modename 0
-                                 (string-match "-mode\\'" modename))))
-           (dolist (suffix suffixes)
-             (let ((sym (intern-soft (concat name suffix))))
-               (when (and sym (boundp sym))
-                 (setq guess sym))))))
-       (when guess `((,guess . ,size))))
-     (and (local-variable-p 'smie-rules-function)
-          `((smie-indent-basic . ,size))))))
-
-(defun editorconfig--get-indentation (style &optional size tab_width)
-  "Get indentation vars according to STYLE, SIZE, and TAB_WIDTH."
-  (if tab_width (setq tab_width (string-to-number tab_width)))
-
+(defun editorconfig-set-indentation (style &optional size tab_width)
+  "Set indentation type from STYLE, SIZE and TAB_WIDTH."
   (setq size
         (cond ((editorconfig-string-integer-p size)
                (string-to-number size))
               ((equal size "tab")
-               (or tab_width tab-width))
+               "tab")
               (t
                nil)))
 
-  `(,@(cond (tab_width `((tab-width . ,tab_width)))
-            ((numberp size) `((tab-width . ,size))))
+  (cond ((not (editorconfig--should-set 'tab-width))
+         nil)
+        (tab_width
+         (setq tab-width (string-to-number tab_width)))
+        ((numberp size)
+         (setq tab-width size)))
 
-    ,@(pcase style
-        ("space" `((indent-tabs-mode . nil)))
-        ("tab" `((indent-tabs-mode . t))))
+  (when (equal size "tab")
+    (setq size tab-width))
 
-    ,@(when (and size (featurep 'evil))
-        `((evil-shift-width . ,size)))
+  (cond ((not (editorconfig--should-set 'indent-tabs-mode))
+         nil)
+        ((equal style "space")
+         (setq indent-tabs-mode nil))
+        ((equal style "tab")
+         (setq indent-tabs-mode t)))
 
-    ,@(cond
-       ((null size) nil)
-       ((functionp editorconfig-indent-size-vars)
-        (funcall editorconfig-indent-size-vars size))
-       (t (mapcar (lambda (v) `(,v . ,size))
-                  editorconfig-indent-size-vars)))))
-
-
-(defun editorconfig-set-indentation (style &optional size tab_width)
-  "Set indentation type from STYLE, SIZE and TAB_WIDTH."
-  (dolist (setting (editorconfig--get-indentation style size tab_width))
-    (when (editorconfig--should-set (car setting))
-      (set (make-local-variable (car setting)) (cdr setting)))))
+  (when size
+    (when (and (featurep 'evil)
+               (editorconfig--should-set 'evil-shift-width))
+      (setq-local evil-shift-width size))
+    (let ((parent major-mode)
+          entry)
+      ;; Find the closet parent mode of `major-mode' in
+      ;; `editorconfig-indentation-alist'.
+      (while (and (not (setq entry (assoc parent editorconfig-indentation-alist)))
+                  (setq parent (get parent 'derived-mode-parent))))
+      (when entry
+        (let ((fn-or-list (cdr entry)))
+          (cond ((functionp fn-or-list) (funcall fn-or-list size))
+                ((listp fn-or-list)
+                 (dolist (elem fn-or-list)
+                   (cond ((and (symbolp elem)
+                               (editorconfig--should-set elem))
+                          (set (make-local-variable elem) size))
+                         ((and (consp elem)
+                               (editorconfig--should-set (car elem)))
+                          (let ((spec (cdr elem)))
+                            (set (make-local-variable (car elem))
+                                 (cond ((functionp spec) (funcall spec size))
+                                       ((integerp spec) (* spec size))
+                                       (t spec))))))))))))))
 
 (defvar-local editorconfig--apply-coding-system-currently nil
   "Used internally.")
@@ -837,21 +824,17 @@ F is that function, and FILENAME and ARGS are arguments passed to F."
 (defun editorconfig--get-coding-system (&optional _size)
   "Return the coding system to use according to EditorConfig.
 Meant to be used on `auto-coding-functions'."
-  ;; Not only we don't want that an error in the `.editorconfig' file
-  ;; prevents opening a file but we don't want an error to be dropped on
-  ;; the floor by some `ignore-errors' higher up.
-  (with-demoted-errors "EditorConfig: %S"
-    (when (and (stringp auto-coding-file-name)
-               (file-name-absolute-p auto-coding-file-name)
-	       ;; Don't recurse infinitely.
-	       (not (member auto-coding-file-name
-	                    editorconfig--getting-coding-system)))
-      (let* ((editorconfig--getting-coding-system
-              (cons auto-coding-file-name editorconfig--getting-coding-system))
-             (props (editorconfig-call-get-properties-function
-                     auto-coding-file-name)))
-        (editorconfig-merge-coding-systems (gethash 'end_of_line props)
-                                           (gethash 'charset props))))))
+  (when (and (stringp auto-coding-file-name)
+             (file-name-absolute-p auto-coding-file-name)
+	     ;; Don't recurse infinitely.
+	     (not (member auto-coding-file-name
+	                  editorconfig--getting-coding-system)))
+    (let* ((editorconfig--getting-coding-system
+            (cons auto-coding-file-name editorconfig--getting-coding-system))
+           (props (editorconfig-call-get-properties-function
+                   auto-coding-file-name)))
+      (editorconfig-merge-coding-systems (gethash 'end_of_line props)
+                                         (gethash 'charset props)))))
 
 ;;;###autoload
 (define-minor-mode editorconfig-mode
